==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 */
$lang['menu']                  = 'Gerir Plugins';
$lang['download']              = 'Descarregar e instalar um novo plugin';
$lang['manage']                = 'Plugins Instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'remover';
$lang['btn_settings']          = 'configurações';
$lang['btn_download']          = 'Descarregar';
$lang['btn_enable']            = 'Guardar';
$lang['installed']             = 'Instalado em:';
$lang['lastupdate']            = 'Actualizado em:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'desconhecida';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'Plugin %s actualizado com sucesso.';
$lang['updates']               = 'Os seguintes plguins foram actualizados com sucesso:';
$lang['update_none']           = 'Não foram encontradas actualizações.';
$lang['deleting']              = 'Removendo ...';
$lang['deleted']               = 'Plugin %s removido.';
$lang['downloading']           = 'Descarregando ...';
$lang['downloaded']            = 'Plugin %s instalado com sucesso.';
$lang['downloads']             = 'Os seguintes plguins foram instalados com sucesso:';
$lang['download_none']         = 'Nenhum plugin encontrado ou ocorreu um problema ao descarregar ou instalar.';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin não retornou qualquer informação, pode estar inválido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrição:';
$lang['author']                = 'Autor:';
$lang['error']                 = 'Ocorreu um erro desconhecido.';
$lang['error_download']        = 'Impossível descarregar o ficheiro do plugin: %s';
$lang['error_badurl']          = 'URL suspeito ou errado - impossível determinar o ficheiro a partir do URL';
$lang['error_dircreate']       = 'Impossível criar pasta temporária para receber os ficheiros a descarregar';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 */
$lang['menu']                  = 'Gerir Plugins';
$lang['download']              = 'Descarregar e instalar um novo plugin';
$lang['manage']                = 'Plugins Instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'remover';
$lang['btn_settings']          = 'configurações';
$lang['btn_download']          = 'Descarregar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado em:';
$lang['lastupdate']            = 'Actualizado em:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'desconhecida';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'Plugin %s actualizado com sucesso.';
$lang['updates']               = 'Os seguintes plguins foram actualizados com sucesso:';
$lang['update_none']           = 'Não foram encontradas actualizações.';
$lang['deleting']              = 'Removendo ...';
$lang['deleted']               = 'Plugin %s removido.';
$lang['downloading']           = 'Descarregando ...';
$lang['downloaded']            = 'Plugin %s instalado com sucesso.';
$lang['downloads']             = 'Os seguintes plguins foram instalados com sucesso:';
$lang['download_none']         = 'Nenhum plugin encontrado ou ocorreu um problema ao descarregar ou instalar.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin não retornou qualquer informação, pode estar inválido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrição:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Sítio:';
$lang['error']                 = 'Ocorreu um erro desconhecido.';
$lang['error_download']        = 'Impossível descarregar o ficheiro do plugin: %s';
$lang['error_badurl']          = 'URL suspeito ou errado - impossível determinar o ficheiro a partir do URL';
$lang['error_dircreate']       = 'Impossível criar pasta temporária para receber os ficheiros a descarregar';
